@@ -20,15 +20,65 @@
 provides "generic container" services
 """
 
+import sys
+from os.path import join
 import logging
 from collections import deque, defaultdict
 
-from logilab.common.decorators import cached
+from logilab.common.decorators import monkeypatch, cached
+from logilab.common.modutils import cleanup_sys_modules
+
+from yams.reader import SchemaLoader, fill_schema
 from yams.buildobjs import DEFAULT_RELPERMS, RelationType, RelationDefinition
 
+
 from cubicweb import neg_role, schema as cw_schema
 from cubicweb.predicates import EntityPredicate, is_instance
 
+cw_schema.META_RTYPES.update(('container_etype', 'container_parent'))
+
+
+
+# Add schema.fs til yams gets it.
+
+@monkeypatch(SchemaLoader)
+def load(self, directories, name=None,
+         register_base_types=True, construction_mode='strict',
+         remove_unused_rtypes=True):
+    """return a schema from the schema definition read from <directory>
+    """
+    self.defined = {}
+    self.loaded_files = []
+    self.post_build_callbacks = []
+    sys.modules[__name__].context = self
+    # ensure we don't have an iterator
+    directories = tuple(directories)
+    try:
+        self._load_definition_files(directories)
+        schema = self.schemacls(name or 'NoName', construction_mode=construction_mode)
+        schema.fs = True
+        try:
+            fill_schema(schema, self.defined, register_base_types,
+                        remove_unused_rtypes=remove_unused_rtypes,
+                        post_build_callbacks=self.post_build_callbacks)
+        except Exception, ex:
+            if not hasattr(ex, 'schema_files'):
+                ex.schema_files = self.loaded_files
+            raise ex, None, sys.exc_info()[-1]
+    finally:
+        # cleanup sys.modules from schema modules
+        # ensure we're only cleaning schema [sub]modules
+        directories = [(not directory.endswith(self.main_schema_directory)
+                        and join(directory, self.main_schema_directory)
+                        or directory)
+                       for directory in directories]
+        cleanup_sys_modules(directories)
+    schema.loaded_files = self.loaded_files
+    return schema
+
+
+
+
 LOGGER = logging.getLogger('cubes.container')
 cw_schema.META_RTYPES.update(('container_etype', 'container_parent'))
 
@@ -103,6 +153,10 @@ class is_in_container(EntityPredicate):
         return 1
 
 
+def _fix_module(src, dest):
+    for attr in dir(dest):
+        setattr(src, attr, getattr(dest, attr))
+
 # Map of container entity type to corresponding container configuration.
 CONTAINERS = {}
 
@@ -129,6 +183,14 @@ class ContainerConfiguration(object):
 
     def __init__(self, etype, rtype, skiprtypes=(), skipetypes=(),
                  subcontainers=()):
+        if not CONTAINERS:
+            # now we put a trick in place
+            from cubes.container.entities import compat as _ecompat
+            from cubes.container import entities as _entities
+            _fix_module(_entities, _ecompat)
+            from cubes.container.hooks import compat as _hcompat
+            from cubes.container import hooks as _hooks
+            _fix_module(_hooks, _hcompat)
         self.etype = etype
         self.rtype = rtype
         self.skiprtypes = frozenset(skiprtypes)
