@@ -2,6 +2,9 @@ from contextlib import contextmanager
 
 from cubicweb.schema import (META_RTYPES, WORKFLOW_DEF_RTYPES, SYSTEM_RTYPES,
                              SCHEMA_TYPES, WORKFLOW_TYPES, INTERNAL_TYPES)
+
+from cubes.fastimport.testutils import FastImportTC
+
 from cubes.container import CONTAINERS, ContainerConfiguration
 
 
@@ -43,6 +46,14 @@ def new_card(req, contents=u"Let's start a spec ..."):
     return req.create_entity('Card', contents=contents)
 
 
+def rdefrepr(rdef):
+    """ rdef -> (rtype, subject type, object type) """
+    return  (rdef.rtype.type, rdef.subject.type, rdef.object.type)
+
+
+ContainerTC = FastImportTC
+
+
 def rtypes_etypes_not_in_container(schema, container_config):
     """Return the sets of entity types and relations types not in the
     container."""
